<?php

namespace Drupal\media_pixabay\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class PixabayApiConfigForm extends ConfigFormBase {

  /**
   * Config settings.
   */
  const SETTINGS = 'media_pixabay.admin.config';

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'pixabay_api_key_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(static::SETTINGS);
    $form['media_pixabay_api'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pixabay API key'),
      '#default_value' => $config->get('media_pixabay_api'),
      '#description' => $this->t('Register on Pixabay.com and get your API key <a href="https://pixabay.com/api/docs/#api_key" target="_blank">here</a>.'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('media_pixabay_api', $form_state->getValue('media_pixabay_api'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
