<?php

namespace Drupal\media_pixabay_test\Api;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\media_pixabay\Api\PixabayApiServiceInterface;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\BadResponseException;
use GuzzleHttp\Psr7\Request;
use GuzzleHttp\Psr7\Response;

/**
 * Provides a connection to Pixabay Api for retrieving images.
 *
 * @package Drupal\media_pixabay_test\Api
 */
class PixabayApiService implements PixabayApiServiceInterface {

  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected ClientInterface $httpClient;

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $config;

  /**
   * PixabayApiService constructor.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   Http client.
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   Configuration factory.
   */
  public function __construct(ClientInterface $http_client, ConfigFactory $config_factory) {
    $this->httpClient = $http_client;
    $this->config = $config_factory->get('media_pixabay_test.api');
  }

  /**
   * {@inheritDoc}
   */
  public function apiCall(string $queryStr): mixed {
    if ($this->config->get('response') === 'exception') {
      throw new BadResponseException('test', new Request('GET', 'https://httpstat.us/400'), new Response());
    }
    else {
      return json_decode($this->config->get('response'));
    }
  }

}
